@@ -31,9 +31,6 @@
 
 #include "vktransport.h"
 
-// Name of library that used for connection (without extension)
-#define LIBNAME "libfacebook"
-
 // Name of exported function
 #define MODULE_INIT "msa_module_init"
 
@@ -64,14 +61,15 @@
 #define VK_OLD_REQUEST "/string[@name='oldRequest']"
 #define VK_FUNCTION "//Response/@function"
 #define VK_WAS_AUTH "//Response/@authorized"
-#define VK_FROM "//array/@from"
-#define VK_TO "//array/@to"
+#define VK_FROM "//array/@page"
+#define VK_TO "//array/@pageSize"
+#define VK_QUANT "//array[@name='messageList']/@quantity"
 #define VK_QUANTITY "//string[@name='quantity']"
-#define VK_PARAMS "//TransitData/Content/Response/Params"
+#define VK_PARAMS "//Response/Params"
 #define LIMIT 10000;
 
 VkTransport::VkTransport(QByteArray name)
-    : msa(0),
+    : msa(0), driverModule(0),
     needShutdown(false),
     activeRequests(0)
 {
@@ -153,11 +151,14 @@ void VkTransport::vkCleareRemoved() {
 void VkTransport::vkGetProfile()
 {
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='profile' function='getBaseProfile'>")
-              + QString("<Params /></Request></Content></TransitData>");
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='profile' function='getBaseProfile'>")
+              + QString("<Params /></Request>")
+//              + QString("</Content></TransitData>")
+            ;
     vkSendRequest(reqStr.toUtf8());
 }
 
@@ -166,10 +167,10 @@ void VkTransport::vkGetProfile(QByteArray captchaCode, QByteArray captchaText)
     qDebug() << "Captcha code:" << captchaCode
              << "Captcha text:" << captchaText;
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content>")
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
               + QString("<Request class='systemMessages' function = 'captchaMessage'>")
               + QString("<Params>")
               + QString("<string name='moduleName'>vk</string>")
@@ -183,50 +184,58 @@ void VkTransport::vkGetProfile(QByteArray captchaCode, QByteArray captchaText)
               + QString("<string name='fccode'>%1</string>").arg(QString(captchaText))
               + QString("</Params>")
               + QString("</Request>")
-              + QString("</string></Params></Request></Content></TransitData>");
+              + QString("</string></Params></Request>")
+//              + QString("</Content></TransitData>")
+            ;
     vkSendRequest(reqStr.toUtf8());
 }
 
-void VkTransport::vkGetSend(int reqFrom = 0,
-                             int reqTo = VK_MESSAGES_AT_ONCE)
+void VkTransport::vkGetSend(int page = 1,
+                            int pageSize = VK_MESSAGES_AT_ONCE)
 {
     // Debug message for calling function
     qDebug() << __FILE__<<":"<< __LINE__
-             << ": Called vkGetSend("<< reqFrom << ", " << reqTo <<");";
+            << ": Called vkGetInbox("<< page << ", " << pageSize <<");";
     // Add XML data to "request" string
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'updateOutboxMessages'>"
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getListOutboxMessages'>"
        << "<Params>"
-       << "<number name='from'>" << reqFrom << "</number>"
-       << "<number name='to'>" << reqTo << "</number>"
-       << "</Params></Request></Content></TransitData>";
+       << "<number name='page'>" << page << "</number>"
+       << "<number name='pageSize'>" << pageSize << "</number>"
+       << "</Params></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
 }
 
-void VkTransport::vkGetInbox(int reqFrom = 0,
-                             int reqTo = VK_MESSAGES_AT_ONCE)
+void VkTransport::vkGetInbox(int page = 1,
+                             int pageSize = VK_MESSAGES_AT_ONCE)
 {
     // Debug message for calling function
     qDebug() << __FILE__<<":"<< __LINE__
-             << ": Called vkGetInbox("<< reqFrom << ", " << reqTo <<");";
+             << ": Called vkGetInbox("<< page << ", " << pageSize <<");";
     // Add XML data to "request" string
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'updateInboxMessages'>"
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getListInboxMessages'>"
        << "<Params>"
-       << "<number name='from'>" << reqFrom << "</number>"
-       << "<number name='to'>" << reqTo << "</number>"
-       << "</Params></Request></Content></TransitData>";
+       << "<number name='page'>" << page << "</number>"
+       << "<number name='pageSize'>" << pageSize << "</number>"
+       << "</Params></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
     //qDebug() << "vkGetInbox(): OK" << endl;
@@ -241,11 +250,14 @@ void VkTransport::vkGetInboxCount()
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'getTotalCountInbox'>"
-       << "<Params/></Request></Content></TransitData>";
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getTotalCountInbox'>"
+       << "<Params/></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
     //qDebug() << "vkGetInbox(): OK" << endl;
@@ -260,13 +272,16 @@ void VkTransport::vkGetInboxCount(QByteArray timeOffset)
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'getCountInboxByTime'>"
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getCountInboxByTime'>"
        << "<Params>"
        << "<number name='timeOffset'>" << timeOffset << "</number>"
-       << "</Params></Request></Content></TransitData>";
+       << "</Params></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
     //qDebug() << "vkGetInbox(): OK" << endl;
@@ -281,11 +296,14 @@ void VkTransport::vkGetOutboxCount()
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'getTotalCountOutbox'>"
-       << "<Params/></Request></Content></TransitData>";
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getTotalCountOutbox'>"
+       << "<Params/></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
     //qDebug() << "vkGetInbox(): OK" << endl;
@@ -300,13 +318,16 @@ void VkTransport::vkGetOutboxCount(QByteArray timeOffset)
     QByteArray reqStr;
     QTextStream ts(&reqStr);
     ts << "<?xml version='1.0'?>"
-       << "<TransitData id='1' type='data'>"
-       << "<SourceID>" << accountName << "</SourceID>"
-       << "<TargetID>" << this->driverModule->id << "</TargetID>"
-       << "<Content><Request class='messages' function = 'getCountOutboxByTime'>"
+//       << "<TransitData id='1' type='data'>"
+//       << "<SourceID>" << accountName << "</SourceID>"
+//       << "<TargetID>" << this->driverModule->id << "</TargetID>"
+//       << "<Content>"
+       << "<Request class='messages' function = 'getCountOutboxByTime'>"
        << "<Params>"
        << "<number name='timeOffset'>" << timeOffset << "</number>"
-       << "</Params></Request></Content></TransitData>";
+       << "</Params></Request>"
+//       << "</Content></TransitData>"
+    ;
     ts.flush();
     vkSendRequest(reqStr);
     //qDebug() << "vkGetInbox(): OK" << endl;
@@ -354,13 +375,15 @@ void VkTransport::vkGetSettings()
     qDebug() << __FILE__<<":"<< __LINE__<<": Call vkGetSettings()";
 
     QString reqStr = QString("<?xml version='1.0'?>")
-                     + QString("<TransitData id='1' type='data'>")
-                     + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-                     + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-                     + QString("<Content>")
+//                     + QString("<TransitData id='1' type='data'>")
+//                     + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//                     + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//                     + QString("<Content>")
                      + QString("<Request class='settings' function='getSettings'>")
                      + QString("<Params/>")
-                     + QString("</Request></Content></TransitData>");
+                     + QString("</Request>")
+//                     + QString("</Content></TransitData>")
+                ;
     vkSendRequest(reqStr.toUtf8());
 }
 
@@ -372,11 +395,14 @@ void VkTransport::vkTestConnection()
     qDebug() << __FILE__<<":"<< __LINE__<<": Call vkTestConnection()";
 
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='settings' function='testConnection'>")
-              + QString("</Request></Content></TransitData>");
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='settings' function='testConnection'>")
+              + QString("</Request>")
+//              + QString("</Content></TransitData>")
+          ;
     vkSendRequest(reqStr.toUtf8());
 }
 
@@ -390,25 +416,31 @@ void VkTransport::vkSetSettings(QString authParams)
     qDebug() << __FILE__<<":"<< __LINE__<<": Call vkSetSettings()";
 
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='settings' function='setSettings'>")
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='settings' function='setSettings'>")
               + authParams
-              + QString("</Request></Content></TransitData>");
+              + QString("</Request>")
+//              + QString("</Content></TransitData>")
+           ;
     vkSendRequest(reqStr.toUtf8());
 }
 
 void VkTransport::vkSendMessage(QByteArray strRecipientId, QByteArray strText="")
 {
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='messages' function='sendMessage'>")
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='messages' function='sendMessage'>")
               + QString("<Params id='vk%1'>").arg(QString(strRecipientId))
               + QString("<string name='text'>%1</string>").arg(QString(strText))
-              + QString("</Params></Request></Content></TransitData>");
+              + QString("</Params></Request>")
+//              + QString("</Content></TransitData>")
+           ;
     vkSendRequest(reqStr.toUtf8());
 }
 
@@ -416,26 +448,32 @@ void VkTransport::vkReadMessage(QString messageId)
 {
     qDebug() << "init VkTransport::vkReadMessage";
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='messages' function='readMessage'>")
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='messages' function='readMessage'>")
               + QString("<Params>")
               + QString("<string name='messageId'>vk%1</string>").arg(messageId)
-              + QString("</Params></Request></Content></TransitData>");
+              + QString("</Params></Request>")
+//              + QString("</Content></TransitData>")
+          ;
     vkSendRequest(reqStr.toUtf8());
 }
 
 void VkTransport::vkDeleteMessage(QString messageId)
 {
     QString reqStr = QString("<?xml version='1.0'?>")
-              + QString("<TransitData id='1' type='data'>")
-              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
-              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
-              + QString("<Content><Request class='messages' function='deleteMessage'>")
+//              + QString("<TransitData id='1' type='data'>")
+//              + QString("<SourceID>%1</SourceID>").arg(accountName.data())
+//              + QString("<TargetID>%1</TargetID>").arg(this->driverModule->id)
+//              + QString("<Content>")
+              + QString("<Request class='messages' function='deleteMessage'>")
               + QString("<Params>")
               + QString("<string name='messageId'>vk%1</string>").arg(messageId)
-              + QString("</Params></Request></Content></TransitData>");
+              + QString("</Params></Request>")
+//              + QString("</Content></TransitData>")
+              ;
     vkSendRequest(reqStr.toUtf8());
 }
 
@@ -603,7 +641,7 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
             qDebug("Info message:");
         }
 
-        if ((parsedString = parseString(VK_RESP_CODE,respContext)) != 0) {
+        if ((parsedString = parseString(VK_RESP_CODE,respContext,false)) != 0) {
             qDebug() << "Code: " << parsedString;
             response->code = QByteArray(parsedString);
             delete [] parsedString;
@@ -612,12 +650,12 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
             qWarning() << "Info/Error code not found.";
         }
 
-        if ((parsedString = parseString(VK_RESP_TEXT,respContext)) != 0) {
+        if ((parsedString = parseString(VK_RESP_TEXT,respContext,false)) != 0) {
             qDebug() << "Text: " << decoder->toUnicode(parsedString);
             response->text = new QString(parsedString);
             delete [] parsedString;
         } else {
-            response->text = new QString("Some message");
+            response->text = new QString("");
             qWarning() << "Info/Error text not found.";
         }
 
@@ -723,8 +761,8 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
         emit responseReceived(response);
     } else
     // Inbox/outbox message
-    if ((sent = (strcmp(functionName,"updateOutboxMessages") == 0))
-        || (strcmp(functionName,"updateInboxMessages") == 0)) {
+    if ((sent = ((strcmp(functionName,"updateOutboxMessages") == 0) || (strcmp(functionName,"getListOutboxMessages") == 0)))
+        || (strcmp(functionName,"updateInboxMessages") == 0) || (strcmp(functionName,"getListInboxMessages") == 0)) {
 
         response->action = sent
                            ? VkTransport::updateOutboxMessagesAction
@@ -746,6 +784,14 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
         int inboxTo = QString(parsedString).toInt();
         delete [] parsedString;
 
+        // Parse Quantity String
+        if ((parsedString = parseString(VK_QUANT,respContext)) == 0) {
+            qDebug() << __FILE__<< ":" << "\"To\" not found" << endl;
+            return;
+        }
+        int inboxQuant = QString(parsedString).toInt();
+        delete [] parsedString;
+
         // Parse To String
         //if ((parsedString = parseString(VK_QUANTITY,respContext)) == 0) {
         //    qDebug() << __FILE__<< ":" << "\"Quantity\" not found" << endl;
@@ -762,9 +808,10 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
                 inboxQuantity=totalInboxCount;
         }
 
-        qDebug() << "From =" << inboxFrom
-                 << "To ="   << inboxTo
-                 << "Quantity ="   << inboxQuantity;
+        qDebug() << "Page =" << inboxFrom
+                 << "PageSize ="   << inboxTo
+                 << "Quantity ="   << inboxQuantity
+                 << "Quant ="      << inboxQuant;
 
         // returned 0 messages
         if (inboxFrom >= inboxTo) {
@@ -775,7 +822,7 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
         QMailMessage *message;
 
         // Parse messages from response
-        for (int index=1; index<=inboxTo-inboxFrom; index++) {
+        for (int index=1; index<=inboxQuant; index++) {
 
             // if receiving chanceled or duplicated messages
             if (response->text)
@@ -851,13 +898,14 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
                 message->setFrom(QMailAddress(decoder->toUnicode(senderName), senderId));
             }
             // Count of recipients
-            int recipients;
+            int recipients=0;
             xpathRequestBufferPointer = stpcpy (xpathRequestBufferCurrentPointer, VK_COUNT_RECIPIENTS);
-            if ((parsedString = parseString(xpathRequestBuffer, respContext)) != 0) {
+            if ((parsedString = parseString(xpathRequestBuffer, respContext, false)) != 0) {
                 recipients=QString(parsedString).toUInt();
                 delete [] parsedString;
             }
 
+            qDebug() << "Recipients: " << recipients;
             QList<QMailAddress> to;
             QByteArray recipientId;
             QByteArray recipientName;
@@ -888,6 +936,10 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
                 }
                 to.append(QMailAddress(decoder->toUnicode(recipientName), recipientId));
             }
+
+            // For vkontakte service
+            if (!sent && recipients==0)
+                to.append(QMailAddress(userName, userId+vkFakeAdress));
             message->setTo(to);
             // Time
             xpathRequestBufferPointer = stpcpy (xpathRequestBufferCurrentPointer, VK_TIME);
@@ -942,10 +994,10 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
             emit pushNewMessage(message);
         }
 
-        response->midFrom = QByteArray(QByteArray::number(inboxTo));
-        response->midTo = QByteArray(QByteArray::number(inboxQuantity));
-
-        if (inboxTo == inboxQuantity) {
+        response->midFrom = QByteArray(QByteArray::number(inboxFrom));
+        response->midTo = QByteArray(QByteArray::number(inboxQuant));
+        //inboxTo == inboxQuantity ||
+        if ( inboxQuant == 0 || inboxQuant < inboxTo ) {
             qDebug() << "Retrivied last message." << endl;
             response->text = new QString("inboxTo == inboxQuantity");
         }
