@@ -55,6 +55,9 @@
 // id of client in requests to library
 #define CLIENT_NAME "fb_client"
 
+// Name of library that used for connection (without extension)
+#define LIBNAME "libmsafb"
+
 #define VK_AT '@'
 #define VK_FAKE_ADDRESS "@fb.com"
 #define VK_FAKE_ADDRESS_PATTERN "\\d+@fb\\.com"
@@ -182,6 +185,7 @@ private:
 
     // Counter for requests to library
     long activeRequests;
+
 };
 
 class VkResponse {
